@@ -19,7 +19,7 @@ Boston, MA 02111-1307, USA.
 *-GNU-GPL-END-*/
 
 /*
-  $Id: ruli_conf.c,v 1.2 2003/02/13 01:59:26 evertonm Exp $
+  $Id: ruli_conf.c,v 1.3 2004/05/21 18:23:50 evertonm Exp $
  */
 
 
@@ -105,7 +105,7 @@ static int conf_load_search_list(ruli_list_t *search_list)
 	    break;
 
 	  /* Allocate space for domain name */
-	  dom = ruli_malloc(sizeof(ruli_domain_t));
+	  dom = (ruli_domain_t *) ruli_malloc(sizeof(ruli_domain_t));
 	  if (!dom)
 	    break;
 
@@ -174,7 +174,7 @@ static int conf_load_search_list(ruli_list_t *search_list)
 
 ruli_list_t *ruli_conf_load_search_list(ruli_conf_handler_t *bogus)
 {
-  ruli_list_t *search_list = ruli_malloc(sizeof(ruli_list_t));
+  ruli_list_t *search_list = (ruli_list_t *) ruli_malloc(sizeof(ruli_list_t));
   if (!search_list)
     return 0;
 
@@ -271,7 +271,7 @@ static int load_ns_list(ruli_list_t *ns_list)
 	  if (!inet_aton(tok, &addr))
 	    break;
 
-	  ad = ruli_malloc(sizeof(struct in_addr));
+	  ad = (struct in_addr *) ruli_malloc(sizeof(struct in_addr));
 	  if (!ad)
 	    break;
 
@@ -314,7 +314,7 @@ static int load_ns_list(ruli_list_t *ns_list)
 
 ruli_list_t *ruli_conf_load_ns_list(ruli_conf_handler_t *bogus)
 {
-  ruli_list_t *ns_list = ruli_malloc(sizeof(ruli_list_t));
+  ruli_list_t *ns_list = (ruli_list_t *) ruli_malloc(sizeof(ruli_list_t));
   if (!ns_list)
     return 0;
 
