@@ -19,7 +19,7 @@ Boston, MA 02111-1307, USA.
 *-GNU-GPL-END-*/
 
 /*
-  $Id: ruli_fsm.c,v 1.17 2003/03/15 05:39:08 evertonm Exp $
+  $Id: ruli_fsm.c,v 1.18 2004/05/21 18:23:50 evertonm Exp $
 
 
   TIMEOUT NOTES:
@@ -118,7 +118,7 @@ static void *query_done_now(oop_source *oop_src,
 			    struct timeval sched_tv, 
 			    void *res_qry) 
 {
-  return query_done(res_qry);
+  return query_done((ruli_res_query_t *) res_qry);
 }
 
 static void schedule_immediate_query_done(oop_source *oop_src, 
@@ -168,7 +168,7 @@ static void *on_udp_read_timeout(oop_source *oop_src,
 				 struct timeval sched_tv, 
 				 void *res_qry) 
 {
-  ruli_res_query_t *qry = res_qry;
+  ruli_res_query_t *qry = (ruli_res_query_t *) res_qry;
 
 #ifdef RULI_RES_DEBUG
   fprintf(stderr, 
@@ -225,7 +225,7 @@ static void *on_tcp_read_head_timeout(oop_source *oop_src,
 				      struct timeval sched_tv, 
 				      void *res_qry) 
 {
-  ruli_res_query_t *qry = res_qry;
+  ruli_res_query_t *qry = (ruli_res_query_t *) res_qry;
 
 #ifdef RULI_RES_DEBUG
   fprintf(stderr, 
@@ -242,7 +242,7 @@ static void *on_tcp_read_body_timeout(oop_source *oop_src,
 				      struct timeval sched_tv, 
 				      void *res_qry) 
 {
-  ruli_res_query_t *qry = res_qry;
+  ruli_res_query_t *qry = (ruli_res_query_t *) res_qry;
 
   query_done_read_tcp_body(qry);
 
@@ -696,7 +696,7 @@ static void query_done_connect_tcp(ruli_res_query_t *qry)
 static void *on_udp_write(oop_source *oop_src, int udp_sd, 
 			  oop_event event, void *ctx)
 {
-  ruli_res_t       *res_ctx = ctx;
+  ruli_res_t       *res_ctx = (ruli_res_t *) ctx;
 
   struct in_addr   *curr_server_addr;
   int              curr_server_port;
@@ -725,7 +725,7 @@ static void *on_udp_write(oop_source *oop_src, int udp_sd,
   assert(queries > 0);
 
   for (i = 0; i < queries; ++i) {
-    qry = ruli_list_get(&res_ctx->query_list, i);
+    qry = (ruli_res_query_t *) ruli_list_get(&res_ctx->query_list, i);
     if (qry->status == RULI_QRY_STAT_UDP_WANT_SEND)
       break;
   }
@@ -835,7 +835,7 @@ static int check_answer_flags(ruli_uint16_t flags)
 static void *on_udp_read(oop_source *oop_src, int udp_sd, 
 			 oop_event event, void *ctx)
 {
-  ruli_res_t         *res_ctx = ctx;
+  ruli_res_t         *res_ctx = (ruli_res_t *) ctx;
   ruli_uint8_t       buf[UDP_READ_BUFSZ];
   struct sockaddr_in sa;
   socklen_t          sa_len = sizeof(sa);
@@ -931,7 +931,7 @@ static void *on_udp_read(oop_source *oop_src, int udp_sd,
   assert(!qry->answer_buf);
   assert(qry->answer_code == RULI_CODE_VOID);
 
-  qry->answer_buf = ruli_malloc(rd);
+  qry->answer_buf = (char *) ruli_malloc(rd);
   if (!qry->answer_buf) {
     qry->answer_code = RULI_CODE_MALLOC;
     return query_done(qry);
@@ -988,7 +988,7 @@ static void queries_connect_next(oop_source *oop_src,
    * Scan queries, saving the TCP ones in affected_list
    */
   for (i = 0; i < list_size; ++i) {
-    ruli_res_query_t *qry = ruli_list_get(query_list, i);
+    ruli_res_query_t *qry = (ruli_res_query_t *) ruli_list_get(query_list, i);
 
     /*
      * Analyze only queries in TCP mode
@@ -1020,7 +1020,7 @@ static void queries_connect_next(oop_source *oop_src,
    * Close the socket 
    */
   for (i = 0; i < list_size; ++i) {
-    ruli_res_query_t *qry    = ruli_list_get(&affected_list, i);
+    ruli_res_query_t *qry    = (ruli_res_query_t *) ruli_list_get(&affected_list, i);
     ruli_server_t    *server = ruli_res_get_curr_server(qry);
     
     if (server->tcp_sd != -1) {
@@ -1042,7 +1042,7 @@ static void queries_connect_next(oop_source *oop_src,
    */
 
   for (i = 0; i < list_size; ++i) {
-    ruli_res_query_t *qry    = ruli_list_get(&affected_list, i);
+    ruli_res_query_t *qry    = (ruli_res_query_t *) ruli_list_get(&affected_list, i);
     ruli_server_t    *server = ruli_res_get_curr_server(qry);
 
     /*
@@ -1102,7 +1102,7 @@ static void queries_tcp_connect2write(ruli_list_t *query_list, int tcp_sd)
    */
 
   for (i = 0; i < list_size; ++i) {
-    ruli_res_query_t *qry = ruli_list_get(query_list, i);
+    ruli_res_query_t *qry = (ruli_res_query_t *) ruli_list_get(query_list, i);
       
     if (qry->status == RULI_QRY_STAT_TCP_WANT_CONNECT) {
         ruli_server_t *server = ruli_res_get_curr_server(qry);
@@ -1122,7 +1122,7 @@ static void queries_tcp_connect2write(ruli_list_t *query_list, int tcp_sd)
 static void *on_tcp_connect(oop_source *oop_src, int tcp_sd, 
 			    oop_event event, void *ctx)
 {
-  ruli_res_t *res_ctx = ctx;
+  ruli_res_t *res_ctx = (ruli_res_t *) ctx;
 
   assert(event == OOP_WRITE);
 
@@ -1156,7 +1156,7 @@ static void *on_tcp_connect(oop_source *oop_src, int tcp_sd,
 static void *on_tcp_write(oop_source *oop_src, int tcp_sd, 
 			  oop_event event, void *ctx)
 {
-  ruli_res_t       *res_ctx = ctx;
+  ruli_res_t       *res_ctx = (ruli_res_t *) ctx;
   int              result;
   ruli_res_query_t *qry;
   int              i;
@@ -1177,7 +1177,7 @@ static void *on_tcp_write(oop_source *oop_src, int tcp_sd,
   assert(queries > 0);
 
   for (i = 0; i < queries; ++i) {
-    qry = ruli_list_get(&res_ctx->query_list, i);
+    qry = (ruli_res_query_t *) ruli_list_get(&res_ctx->query_list, i);
     if (qry->status == RULI_QRY_STAT_TCP_WANT_SEND)
       break;
   }
@@ -1365,7 +1365,7 @@ static void *recv_tcp_head(ruli_res_t *ctx, int tcp_sd)
   assert(!qry->answer_buf);
   assert(qry->answer_code == RULI_CODE_VOID);
 
-  qry->answer_buf = ruli_malloc(msg_len);
+  qry->answer_buf = (char *) ruli_malloc(msg_len);
   if (!qry->answer_buf) {
     qry->answer_code = RULI_CODE_MALLOC;
 
@@ -1483,7 +1483,7 @@ static void *recv_tcp_body(ruli_res_query_t *qry, int tcp_sd)
 static void *on_tcp_read(oop_source *oop_src, int tcp_sd, 
 			 oop_event event, void *ctx)
 {
-  ruli_res_t       *res_ctx    = ctx;
+  ruli_res_t       *res_ctx    = (ruli_res_t *) ctx;
   ruli_list_t      *query_list = &res_ctx->query_list;
   int              list_size   = ruli_list_size(query_list);
   ruli_res_query_t *qry;
@@ -1505,7 +1505,7 @@ static void *on_tcp_read(oop_source *oop_src, int tcp_sd,
    */
 
   for (i = 0; i < list_size; ++i) {
-    qry = ruli_list_get(query_list, i);
+    qry = (ruli_res_query_t *) ruli_list_get(query_list, i);
 
     if (get_curr_tcp_socket(qry) == tcp_sd)
       if (qry->status == RULI_QRY_STAT_TCP_WANT_RECV_BODY)
