@@ -19,7 +19,7 @@ Boston, MA 02111-1307, USA.
 *-GNU-GPL-END-*/
 
 /*
-  $Id: ruli_res.c,v 1.25 2003/02/15 06:51:01 evertonm Exp $
+  $Id: ruli_res.c,v 1.26 2004/05/21 18:23:50 evertonm Exp $
   */
 
 
@@ -137,7 +137,7 @@ static void ruli_res_dispose_servers(ruli_res_t *res_ctx)
   ruli_server_t *server;
 
   for (i = 0; i < size; ++i) {
-    server = ruli_list_get(&res_ctx->server_list, i);
+    server = (ruli_server_t *) ruli_list_get(&res_ctx->server_list, i);
     if (server->tcp_sd != -1) {
       int result = close(server->tcp_sd);
       assert(!result);
@@ -255,7 +255,7 @@ int ruli_res_new(ruli_res_t *res_ctx)
   }
 
   for (i = 0; i < size; ++i) {
-    server = ruli_malloc(sizeof(ruli_server_t));
+    server = (ruli_server_t *) ruli_malloc(sizeof(ruli_server_t));
     if (!server) {
       conf_unload(res_ctx);
       ruli_list_delete(&res_ctx->query_list);
@@ -507,7 +507,7 @@ void ruli_res_query_delete(ruli_res_query_t *res_qry)
    * Re-index the query which replaced this, if any.
    */
   if (q_ind != ruli_list_size(q_list)) {
-    ruli_res_query_t *qry = ruli_list_get(q_list, q_ind);
+    ruli_res_query_t *qry = (ruli_res_query_t *) ruli_list_get(q_list, q_ind);
     qry->resolver_index = q_ind;
   }
 
@@ -527,8 +527,8 @@ int ruli_res_get_curr_server_index(ruli_res_query_t *qry)
 
 ruli_server_t *ruli_res_get_curr_server(ruli_res_query_t *qry)
 {
-  return ruli_list_get(&qry->resolver->server_list, 
-		       ruli_res_get_curr_server_index(qry));
+  return (ruli_server_t *) ruli_list_get(&qry->resolver->server_list, 
+		                         ruli_res_get_curr_server_index(qry));
 }
 
 struct in_addr *ruli_res_get_curr_serv_addr(ruli_res_query_t *res_qry)
@@ -542,7 +542,7 @@ struct in_addr *ruli_res_get_curr_serv_addr(ruli_res_query_t *res_qry)
   assert(res_qry->curr_server >= 0);
   assert(res_qry->curr_server < ruli_list_size(res_ctx->ns_list));
 
-  return ruli_list_get(res_ctx->ns_list, res_qry->curr_server);
+  return (struct in_addr *) ruli_list_get(res_ctx->ns_list, res_qry->curr_server);
 }
 
 int ruli_res_get_curr_serv_port(ruli_res_query_t *res_qry)
@@ -554,7 +554,7 @@ int get_curr_tcp_socket(ruli_res_query_t *qry)
 {
   ruli_res_t    *res_ctx = qry->resolver;
   int           i        = ruli_res_get_curr_server_index(qry);
-  ruli_server_t *server  = ruli_list_get(&res_ctx->server_list, i);
+  ruli_server_t *server  = (ruli_server_t *) ruli_list_get(&res_ctx->server_list, i);
   int           tcp_sd   = server->tcp_sd;
 
   return tcp_sd;
@@ -593,7 +593,7 @@ ruli_res_query_t *ruli_res_find_query_by_id(ruli_list_t *query_list,
   query_list_size = ruli_list_size(query_list);
 
   for (i = 0; i < query_list_size; ++i) {
-    qry = ruli_list_get(query_list, i);
+    qry = (ruli_res_query_t *) ruli_list_get(query_list, i);
     if (qry->query_id == query_id)
       return qry;
   }
@@ -614,7 +614,7 @@ ruli_server_t *ruli_res_find_server_by_sd(ruli_list_t *server_list,
   list_size = ruli_list_size(server_list);
 
   for (i = 0; i < list_size; ++i) {
-    server = ruli_list_get(server_list, i);
+    server = (ruli_server_t *) ruli_list_get(server_list, i);
     if (server->tcp_sd == sd)
       return server;
   }
@@ -648,7 +648,7 @@ static const ruli_domain_t *next_search_suffix(ruli_res_query_t *qry)
   assert(qry->search_index >= 0);
   assert(qry->search_index < search_list_size);
 
-  suffix = ruli_list_get(res_ctx->search_list, qry->search_index);
+  suffix = (ruli_domain_t *) ruli_list_get(res_ctx->search_list, qry->search_index);
 
   return suffix;
 }
