@@ -19,7 +19,7 @@ Boston, MA 02111-1307, USA.
 *-GNU-GPL-END-*/
 
 /*
-  $Id: ruli_smtp.c,v 1.4 2004/03/11 19:35:15 evertonm Exp $
+  $Id: ruli_smtp.c,v 1.6 2004/05/21 18:23:50 evertonm Exp $
   */
 
 
@@ -178,9 +178,9 @@ static void *on_mx_answer(ruli_res_query_t *qry, void *qry_arg)
        * Scan answer section for IN MX records
        */
       for (i = 0; i < an_list_size; ++i) {
-	ruli_rr_t *rr = ruli_list_get(an_list, i);
+	ruli_rr_t *rr = (ruli_rr_t *) ruli_list_get(an_list, i);
 
-	if (rr->class != RULI_RR_CLASS_IN)
+	if (rr->qclass != RULI_RR_CLASS_IN)
 	  continue;
 	if (rr->type != RULI_RR_TYPE_MX)
 	  continue;
@@ -219,10 +219,10 @@ static void *on_mx_answer(ruli_res_query_t *qry, void *qry_arg)
 	   */
 	  
 	  for (j = 0; j < ad_list_size; ++j) {
-	    ruli_rr_t      *ad_rr = ruli_list_get(ad_list, j);
+	    ruli_rr_t      *ad_rr = (ruli_rr_t *) ruli_list_get(ad_list, j);
 	    struct in_addr *addr;
 
-	    if (ad_rr->class != RULI_RR_CLASS_IN)
+	    if (ad_rr->qclass != RULI_RR_CLASS_IN)
 	      continue;
 	    if (ad_rr->type != RULI_RR_TYPE_A)
 	      continue;
@@ -245,7 +245,7 @@ static void *on_mx_answer(ruli_res_query_t *qry, void *qry_arg)
 	    if (!srv_entry) {
 	      
 	      /* Create SRV record */
-	      srv_entry = ruli_malloc(sizeof(ruli_srv_entry_t));
+	      srv_entry = (ruli_srv_entry_t *) ruli_malloc(sizeof(ruli_srv_entry_t));
 	      if (!srv_entry) {
 		ruli_parse_delete(&parse);
 		return fall_query_done(srv_qry, RULI_SRV_CODE_FALL_OTHER);
@@ -280,7 +280,7 @@ static void *on_mx_answer(ruli_res_query_t *qry, void *qry_arg)
 	    } /* Create SRV record */
 	    
 	    /* Allocate space */
-	    addr = ruli_malloc(sizeof(struct in_addr));
+	    addr = (struct in_addr *) ruli_malloc(sizeof(struct in_addr));
 	    if (!addr) {
 	      ruli_parse_delete(&parse);
 	      return fall_query_done(srv_qry, RULI_SRV_CODE_FALL_OTHER);
@@ -369,7 +369,7 @@ static void *srv_answer_fallback_smtp(ruli_srv_t *srv_qry)
   /*
    * Allocate space for fallback query
    */
-  srv_qry->fall_query = ruli_malloc(sizeof(ruli_res_query_t));
+  srv_qry->fall_query = (ruli_res_query_t *) ruli_malloc(sizeof(ruli_res_query_t));
   if (!srv_qry->fall_query)
     return _ruli_srv_query_done(srv_qry, RULI_SRV_CODE_FALL_OTHER);
 
