@@ -19,7 +19,7 @@ Boston, MA 02111-1307, USA.
 *-GNU-GPL-END-*/
 
 /*
-  $Id: ruli_srv.c,v 1.54 2004/01/04 05:06:28 evertonm Exp $
+  $Id: ruli_srv.c,v 1.56 2004/05/21 18:23:50 evertonm Exp $
   */
 
 
@@ -121,8 +121,8 @@ static void *on_walk_answer(ruli_res_query_t *qry, void *qry_arg)
   assert(srv_qry->walk_query);
   assert(srv_qry->walk_query == qry);
 
-  srv_entry           = ruli_list_get(&srv_qry->answer_srv_list, 
-				      srv_qry->walk_index);
+  srv_entry = (ruli_srv_entry_t *) ruli_list_get(&srv_qry->answer_srv_list, 
+			      	                 srv_qry->walk_index);
   assert(srv_entry);
 
   addr_list           = &srv_entry->addr_list;
@@ -213,9 +213,9 @@ static void *on_walk_answer(ruli_res_query_t *qry, void *qry_arg)
       int         i;
 
       for (i = 0; i < an_list_size; ++i) {
-	ruli_rr_t *rr = ruli_list_get(an_list, i);
+	ruli_rr_t *rr = (ruli_rr_t *) ruli_list_get(an_list, i);
 
-	if (rr->class != RULI_RR_CLASS_IN)
+	if (rr->qclass != RULI_RR_CLASS_IN)
 	  continue;
 	if (rr->type != RULI_RR_TYPE_A)
 	  continue;
@@ -238,7 +238,7 @@ static void *on_walk_answer(ruli_res_query_t *qry, void *qry_arg)
 	 */
 	{
 	  /* Allocate space */
-	  struct in_addr *addr = ruli_malloc(sizeof(struct in_addr));
+	  struct in_addr *addr = (struct in_addr *) ruli_malloc(sizeof(struct in_addr));
 	  if (!addr) {
 	    ruli_parse_delete(&parse);
 	    return walk_query_done(srv_qry, RULI_SRV_CODE_WALK_OTHER);
@@ -319,8 +319,8 @@ static void *srv_answer_walk(ruli_srv_t *srv_qry)
    * Scan answer targets, considering empty address lists
    */
   for (; srv_qry->walk_index < srv_list_size; ++srv_qry->walk_index) {
-    ruli_srv_entry_t *entry         = ruli_list_get(srv_list, 
-						    srv_qry->walk_index);
+    ruli_srv_entry_t *entry = (ruli_srv_entry_t *) ruli_list_get(srv_list, 
+						   srv_qry->walk_index);
     ruli_list_t      *addr_list     = &entry->addr_list;
     int              addr_list_size = ruli_list_size(addr_list);
 
@@ -349,7 +349,7 @@ static void *srv_answer_walk(ruli_srv_t *srv_qry)
      * Allocate space for auxiliary walk query
      */
     assert(!srv_qry->walk_query);
-    srv_qry->walk_query = ruli_malloc(sizeof(ruli_res_query_t));
+    srv_qry->walk_query = (ruli_res_query_t *) ruli_malloc(sizeof(ruli_res_query_t));
     if (!srv_qry->walk_query)
       return query_done(srv_qry, RULI_SRV_CODE_WALK_OTHER);
 
@@ -519,9 +519,9 @@ static void *on_fallback_answer(ruli_res_query_t *qry, void *qry_arg)
        * 1/3: Scan answer section for IN A records
        */
       for (i = 0; i < an_list_size; ++i) {
-	ruli_rr_t *rr = ruli_list_get(an_list, i);
+	ruli_rr_t *rr = (ruli_rr_t *) ruli_list_get(an_list, i);
 
-	if (rr->class != RULI_RR_CLASS_IN)
+	if (rr->qclass != RULI_RR_CLASS_IN)
 	  continue;
 	if (rr->type != RULI_RR_TYPE_A)
 	  continue;
@@ -546,7 +546,7 @@ static void *on_fallback_answer(ruli_res_query_t *qry, void *qry_arg)
 	  if (!srv_entry) {
 
 	    /* Create record */
-	    srv_entry = ruli_malloc(sizeof(ruli_srv_entry_t));
+	    srv_entry = (ruli_srv_entry_t *) ruli_malloc(sizeof(ruli_srv_entry_t));
 	    if (!srv_entry) {
 	      ruli_parse_delete(&parse);
 	      return fall_query_done(srv_qry, RULI_SRV_CODE_FALL_OTHER);
@@ -581,7 +581,7 @@ static void *on_fallback_answer(ruli_res_query_t *qry, void *qry_arg)
 	  }
 
 	  /* Allocate space */
-	  addr = ruli_malloc(sizeof(struct in_addr));
+	  addr = (struct in_addr *) ruli_malloc(sizeof(struct in_addr));
 	  if (!addr) {
 	    ruli_parse_delete(&parse);
 	    return fall_query_done(srv_qry, RULI_SRV_CODE_FALL_OTHER);
@@ -632,9 +632,9 @@ static void *on_fallback_answer(ruli_res_query_t *qry, void *qry_arg)
       cname_found = 0; /* false */
 
       for (i = 0; i < an_list_size; ++i) {
-	ruli_rr_t *rr = ruli_list_get(an_list, i);
+	ruli_rr_t *rr = (ruli_rr_t *) ruli_list_get(an_list, i);
 
-	if (rr->class != RULI_RR_CLASS_IN)
+	if (rr->qclass != RULI_RR_CLASS_IN)
 	  continue;
 	if (rr->type != RULI_RR_TYPE_CNAME)
 	  continue;
@@ -751,7 +751,7 @@ void *_srv_answer_fallback_addr(ruli_srv_t *srv_qry)
   /*
    * Allocate space for fallback query
    */
-  srv_qry->fall_query = ruli_malloc(sizeof(ruli_res_query_t));
+  srv_qry->fall_query = (ruli_res_query_t *) ruli_malloc(sizeof(ruli_res_query_t));
   if (!srv_qry->fall_query)
     return query_done(srv_qry, RULI_SRV_CODE_FALL_OTHER);
 
@@ -877,9 +877,9 @@ static void *on_srv_answer(ruli_res_query_t *qry, void *arg)
 
     if (ruli_list_size(an_list) == 1) {
 
-      ruli_rr_t *rr = ruli_list_top(an_list);
+      ruli_rr_t *rr = (ruli_rr_t *) ruli_list_top(an_list);
 
-      if (rr->class == RULI_RR_CLASS_IN) {
+      if (rr->qclass == RULI_RR_CLASS_IN) {
 
 	if (rr->type == RULI_RR_TYPE_SRV) {
 
@@ -930,10 +930,10 @@ static void *on_srv_answer(ruli_res_query_t *qry, void *arg)
     int         i;
 
     for (i = 0; i < an_list_size; ++i) {
-      ruli_rr_t        *rr = ruli_list_get(an_list, i);
+      ruli_rr_t        *rr = (ruli_rr_t *) ruli_list_get(an_list, i);
       ruli_srv_rdata_t *srv_rdata;
 
-      if (rr->class != RULI_RR_CLASS_IN)
+      if (rr->qclass != RULI_RR_CLASS_IN)
 	continue;
 
       if (rr->type != RULI_RR_TYPE_SRV)
@@ -958,7 +958,7 @@ static void *on_srv_answer(ruli_res_query_t *qry, void *arg)
       (i + 1), an_list_size);
 #endif
 
-      srv_rdata = ruli_malloc(sizeof(ruli_srv_rdata_t));
+      srv_rdata = (ruli_srv_rdata_t *) ruli_malloc(sizeof(ruli_srv_rdata_t));
       if (!srv_rdata)
 	return query_done(srv_qry, RULI_SRV_CODE_MALLOC);
 
@@ -1003,7 +1003,7 @@ static void *on_srv_answer(ruli_res_query_t *qry, void *arg)
      * Handle every RR based on priority (higher priority first)
      */
     for (j = 0; j < src_list_size; ++j) {
-      ruli_srv_rdata_t *srv_rdata    = ruli_list_get(src_list, j);
+      ruli_srv_rdata_t *srv_rdata    = (ruli_srv_rdata_t *) ruli_list_get(src_list, j);
       ruli_list_t      *dst_list     = &srv_qry->pri_srv_list;
       int              dst_list_size = ruli_list_size(dst_list);
       int              i;
@@ -1014,7 +1014,7 @@ static void *on_srv_answer(ruli_res_query_t *qry, void *arg)
        * Find a lower-or-equal priority
        */
       for (i = 0; i < dst_list_size; ++i) {
-	ruli_srv_rdata_t *rd = ruli_list_get(dst_list, i);
+	ruli_srv_rdata_t *rd = (ruli_srv_rdata_t *) ruli_list_get(dst_list, i);
 
 	if (srv_rdata->priority < rd->priority)
 	  continue;
@@ -1028,7 +1028,7 @@ static void *on_srv_answer(ruli_res_query_t *qry, void *arg)
 	   * Find begin of next priority and insert there
 	   */
 	  for (; i < dst_list_size; ++i) {
-	    ruli_srv_rdata_t *s_rd = ruli_list_get(dst_list, i);
+	    ruli_srv_rdata_t *s_rd = (ruli_srv_rdata_t *) ruli_list_get(dst_list, i);
 
 	    if (srv_rdata->priority != s_rd->priority)
 	      break;
@@ -1100,7 +1100,7 @@ static void *on_srv_answer(ruli_res_query_t *qry, void *arg)
        * Get current priority
        */
       curr          = src_list_size - 1;
-      srv_rd        = ruli_list_get(src_list, curr);
+      srv_rd        = (ruli_srv_rdata_t *) ruli_list_get(src_list, curr);
       curr_priority = srv_rd->priority;
 
       /*
@@ -1108,7 +1108,7 @@ static void *on_srv_answer(ruli_res_query_t *qry, void *arg)
        */
       priority_weight_sum = 0;
       for (i = curr; i >= 0; --i) {
-	ruli_srv_rdata_t *rd = ruli_list_get(src_list, i);
+	ruli_srv_rdata_t *rd = (ruli_srv_rdata_t *) ruli_list_get(src_list, i);
 	  
 	if (curr_priority != rd->priority)
 	  break;
@@ -1131,7 +1131,7 @@ static void *on_srv_answer(ruli_res_query_t *qry, void *arg)
 
 	assert(i >= 0);
 
-	rd = ruli_list_get(src_list, i);
+	rd = (ruli_srv_rdata_t *) ruli_list_get(src_list, i);
 	run_sum += rd->weight;
 
 	if (run_sum < rnd)
@@ -1188,10 +1188,10 @@ static void *on_srv_answer(ruli_res_query_t *qry, void *arg)
 
     /* Scan all targets */
     for (i = 0; i < src_list_size; ++i) {
-      ruli_srv_rdata_t *rd        = ruli_list_get(src_list, i);
+      ruli_srv_rdata_t *rd = (ruli_srv_rdata_t *) ruli_list_get(src_list, i);
 
       /* Create record */
-      ruli_srv_entry_t *srv_entry = ruli_malloc(sizeof(ruli_srv_entry_t));
+      ruli_srv_entry_t *srv_entry = (ruli_srv_entry_t *) ruli_malloc(sizeof(ruli_srv_entry_t));
       if (!srv_entry)
 	return query_done(srv_qry, RULI_SRV_CODE_MALLOC);
 
@@ -1232,10 +1232,10 @@ static void *on_srv_answer(ruli_res_query_t *qry, void *arg)
 
 	/* Scan additional section */
 	for (j = 0; j < ad_list_size; ++j) {
-	  ruli_rr_t      *rr = ruli_list_get(ad_list, j);
+	  ruli_rr_t *rr = (ruli_rr_t *) ruli_list_get(ad_list, j);
 	  struct in_addr *addr;
 
-	  if (rr->class != RULI_RR_CLASS_IN)
+	  if (rr->qclass != RULI_RR_CLASS_IN)
 	    continue;
 
 	  if (rr->type != RULI_RR_TYPE_A)
@@ -1250,7 +1250,7 @@ static void *on_srv_answer(ruli_res_query_t *qry, void *arg)
 	    continue;
 
 	  /* Allocate space for address */
-	  addr = ruli_malloc(sizeof(struct in_addr));
+	  addr = (struct in_addr *) ruli_malloc(sizeof(struct in_addr));
 	  if (!addr)
 	    return query_done(srv_qry, RULI_SRV_CODE_MALLOC);
 
@@ -1331,7 +1331,7 @@ int _ruli_srv_query_submit(ruli_srv_t *srv_qry,
 
     qdomain_len = service_len + srv_qry->srv_domain_len;
 
-    qdomain = ruli_malloc(qdomain_len);
+    qdomain = (char *) ruli_malloc(qdomain_len);
     if (!qdomain)
       return RULI_SRV_MALLOC;
 
@@ -1459,7 +1459,7 @@ void ruli_srv_query_delete(ruli_srv_t *srv_qry)
      * For each entry, release list of *in_addr
      */
     for (i = 0; i < list_size; ++i) {
-      ruli_srv_entry_t *srv_entry = ruli_list_get(list, i);
+      ruli_srv_entry_t *srv_entry = (ruli_srv_entry_t *) ruli_list_get(list, i);
       ruli_list_dispose_trivial(&srv_entry->addr_list);
     }
   }
