@@ -19,7 +19,7 @@ Boston, MA 02111-1307, USA.
 *-GNU-GPL-END-*/
 
 /*
-  $Id: addrsolver3.c,v 1.12 2003/02/13 05:57:47 evertonm Exp $
+  $Id: addrsolver3.c,v 1.13 2004/05/19 23:09:13 evertonm Exp $
  */
 
 
@@ -148,7 +148,7 @@ static void *on_answer(ruli_res_query_t *qry, void *arg)
 
       rr = ruli_list_get(&parse.answer_list, i);
 
-      if (rr->class != RULI_RR_CLASS_IN)
+      if (rr->qclass != RULI_RR_CLASS_IN)
 	continue;
 
       if (rr->type != RULI_RR_TYPE_A)
